

.. image:: https://travis-ci.org/sonofeft/DigiPlot.svg?branch=master
    :target: https://travis-ci.org/sonofeft/DigiPlot

.. image:: https://img.shields.io/pypi/v/DigiPlot.svg
    :target: https://pypi.python.org/pypi/digiplot
        
.. image:: https://img.shields.io/pypi/pyversions/DigiPlot.svg
    :target: https://wiki.python.org/moin/Python2orPython3

.. image:: https://img.shields.io/pypi/l/DigiPlot.svg
    :target: https://pypi.python.org/pypi/digiplot


A Tkinter Code That Helps Users Digitize Curves From Plot Images.
=================================================================


See the Code at: `<https://github.com/sonofeft/DigiPlot>`_

See the Docs at: `<http://digiplot.readthedocs.org/en/latest/>`_

See PyPI page at:`<https://pypi.python.org/pypi/digiplot>`_



If a 2D plot is available only on paper or an image file, but the user needs the x,y data pairs in digital form, DigiPlot will help to create those x,y data pairs.
